@@ -639,7 +639,7 @@ ip_address_filter_cb (GtkEntry *   entry,
 		                                 user_data);
 		gtk_editable_insert_text (editable, result, count, position);
 		g_free (priv->last_edited);
-		priv->last_edited = g_strdup (gtk_editable_get_chars (editable, 0, -1));
+		priv->last_edited = gtk_editable_get_chars (editable, 0, -1);
 		g_signal_handlers_unblock_by_func (G_OBJECT (editable),
 		                                   G_CALLBACK (ip_address_filter_cb),
 		                                   user_data);
@@ -660,7 +660,7 @@ delete_text_cb (GtkEditable *editable,
 
 	/* Keep last_edited up-to-date */
 	g_free (priv->last_edited);
-	priv->last_edited = g_strdup (gtk_editable_get_chars (editable, 0, -1));
+	priv->last_edited = gtk_editable_get_chars (editable, 0, -1);
 }
 
 static gboolean
